pub struct PanicError { /* private fields */ }Expand description
The original payload of a captured unwind panic.
A mutex allows this error to be shared even when the payload is only Send.
Implementations
Sourceimpl PanicError
impl PanicError
Sourcepub fn into_payload(self) -> Box<dyn Any + Send>
pub fn into_payload(self) -> Box<dyn Any + Send>
Recover the original payload for inspection by the caller.